@@ -2,7 +2,7 @@ package Test2::Tools::TypeTiny;
 
 # ABSTRACT: Test2 tools for checking Type::Tiny types
 use version;
-our $VERSION = 'v0.90.0'; # VERSION
+our $VERSION = 'v0.90.1'; # VERSION
 
 use v5.18;
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 
 use parent 'Exporter';
 
-use List::Util v1.29 qw< uniq pairmap >;
+use List::Util v1.29 qw< uniq pairmap pairs >;
 use Scalar::Util     qw< refaddr >;
 
 use Test2::API            qw< context run_subtest >;
@@ -41,10 +41,6 @@ use namespace::clean;
 #pod                 llanfairpwllgwyngllgogerychwyrndrobwllllantysiliogogogoch.co.uk
 #pod             >,
 #pod         );
-#pod         should_fail_initially(
-#pod             $type,
-#pod             qw< www ftp001 ftp001-prod3 .com domains.t x.c >,
-#pod         );
 #pod         should_fail(
 #pod             $type,
 #pod             qw< www ftp001 .com domains.t x.c prod|ask|me -prod3.example.com >,
@@ -156,6 +152,10 @@ sub _should_pass_initially_subtest {
 #pod Creates a L<buffered subtest|Test2::Tools::Subtest/BUFFERED> that confirms the type will fail with
 #pod all of the given C<@values>, without using any coercions.
 #pod
+#pod This function is included for completeness.  However, items in C<should_fail_initially> should
+#pod realistically end up in either a L</should_fail> block (if it always fails, even with coercions) or
+#pod a L</should_coerce_into> block (if it would pass after coercions).
+#pod
 #pod =cut
 
 sub should_fail_initially {
@@ -328,13 +328,11 @@ sub should_coerce_into {
 sub _should_coerce_into_subtest {
     my ($type, @kv_pairs) = @_;
 
-    my %old_new    = @kv_pairs;
-    my @old_values = pairmap { $a } @kv_pairs;
+    plan int( scalar(@kv_pairs) / 2 );
 
-    plan scalar @old_values;
+    foreach my $kv (pairs @kv_pairs) {
+        my ($value, $expected) = @$kv;
 
-    foreach my $value (@old_values) {
-        my $expected    = $old_new{$value};
         my $val_dd      = _dd($value);
         my @val_explain = _constraint_type_check_debug_map($type, $value);
 
@@ -523,7 +521,7 @@ Test2::Tools::TypeTiny - Test2 tools for checking Type::Tiny types
 
 =head1 VERSION
 
-version v0.90.0
+version v0.90.1
 
 =head1 SYNOPSIS
 
@@ -543,10 +541,6 @@ version v0.90.0
                 llanfairpwllgwyngllgogerychwyrndrobwllllantysiliogogogoch.co.uk
             >,
         );
-        should_fail_initially(
-            $type,
-            qw< www ftp001 ftp001-prod3 .com domains.t x.c >,
-        );
         should_fail(
             $type,
             qw< www ftp001 .com domains.t x.c prod|ask|me -prod3.example.com >,
@@ -606,6 +600,10 @@ all of the given C<@values>, without any need for coercions.
 Creates a L<buffered subtest|Test2::Tools::Subtest/BUFFERED> that confirms the type will fail with
 all of the given C<@values>, without using any coercions.
 
+This function is included for completeness.  However, items in C<should_fail_initially> should
+realistically end up in either a L</should_fail> block (if it always fails, even with coercions) or
+a L</should_coerce_into> block (if it would pass after coercions).
+
 =head3 should_pass
 
     should_pass($type, @values);
